@@ -52,7 +52,7 @@ const char* EBook_CHM::URL_SCHEME_CHM = "ms-its";
 EBook_CHM::EBook_CHM()
 	: EBook()
 {
-	m_envOptions = getenv("UCHMVIEWEROPTS");
+	m_envOptions = getenv( "UCHMVIEWEROPTS" );
 	m_chmFile = NULL;
 	m_filename = m_font = QString();
 
@@ -97,10 +97,10 @@ QString EBook_CHM::title() const
 
 QUrl EBook_CHM::homeUrl() const
 {
-	return pathToUrl( encodeWithCurrentCodec(m_home) );
+	return pathToUrl( encodeWithCurrentCodec( m_home ) );
 }
 
-bool EBook_CHM::hasFeature(EBook::Feature code) const
+bool EBook_CHM::hasFeature( EBook::Feature code ) const
 {
 	switch ( code )
 	{
@@ -125,7 +125,7 @@ bool EBook_CHM::getTableOfContents( QList<EBookTocEntry>& toc ) const
 	// Parse the plain text TOC
 	QList< ParsedEntry > parsed;
 
-	if ( !parseFileAndFillArray( encodeWithCurrentCodec(m_topicsFile), parsed, false ) )
+	if ( !parseFileAndFillArray( encodeWithCurrentCodec( m_topicsFile ), parsed, false ) )
 		return false;
 
 	// Find out the root offset, and reduce the indent level to it
@@ -134,13 +134,14 @@ bool EBook_CHM::getTableOfContents( QList<EBookTocEntry>& toc ) const
 
 	// Fill up the real toc
 	toc.reserve( parsed.size() );
+
 	Q_FOREACH ( const ParsedEntry& e, parsed )
 	{
 		if ( root_offset == -1 )
 			root_offset = e.indent;
 
 		EBookTocEntry entry;
-		entry.iconid = (EBookTocEntry::Icon) e.iconid;
+		entry.iconid = ( EBookTocEntry::Icon ) e.iconid;
 		entry.indent = e.indent - root_offset;
 		entry.name = e.name;
 
@@ -153,12 +154,12 @@ bool EBook_CHM::getTableOfContents( QList<EBookTocEntry>& toc ) const
 	return true;
 }
 
-bool EBook_CHM::getIndex(QList<EBookIndexEntry>& index) const
+bool EBook_CHM::getIndex( QList<EBookIndexEntry>& index ) const
 {
 	// Parse the plain text index
 	QList< ParsedEntry > parsed;
 
-	if ( !parseFileAndFillArray( encodeWithCurrentCodec(m_indexFile), parsed, true ) )
+	if ( !parseFileAndFillArray( encodeWithCurrentCodec( m_indexFile ), parsed, true ) )
 		return false;
 
 	// Find out the root offset, and reduce the indent level to it
@@ -208,7 +209,7 @@ bool EBook_CHM::getFileContentAsString( QString& str, const QUrl& url ) const
 
 bool EBook_CHM::getFileContentAsBinary( QByteArray& data, const QUrl& url ) const
 {
-	return getBinaryContent( data, urlToPath(url) );
+	return getBinaryContent( data, urlToPath( url ) );
 }
 
 bool EBook_CHM::getBinaryContent( QByteArray& data, const QString& url ) const
@@ -220,7 +221,7 @@ bool EBook_CHM::getBinaryContent( QByteArray& data, const QString& url ) const
 
 	data.resize( ui.length );
 
-	if ( RetrieveObject( &ui, (unsigned char*) data.data(), 0, ui.length ) )
+	if ( RetrieveObject( &ui, ( unsigned char* ) data.data(), 0, ui.length ) )
 		return true;
 
 	return false;
@@ -247,7 +248,7 @@ bool EBook_CHM::getTextContent( QString& str, const QString& url, bool internal_
 	return false;
 }
 
-int EBook_CHM::getContentSize(const QString& url)
+int EBook_CHM::getContentSize( const QString& url )
 {
 	chmUnitInfo ui;
 
@@ -257,7 +258,7 @@ int EBook_CHM::getContentSize(const QString& url)
 	return ui.length;
 }
 
-bool EBook_CHM::load(const QString& archiveName)
+bool EBook_CHM::load( const QString& archiveName )
 {
 	QString filename;
 
@@ -277,9 +278,9 @@ bool EBook_CHM::load(const QString& archiveName)
 	// however internally it simply passes the filename
 	// directly to CreateFileW function without any conversion.
 	// Thus we need to pass it as WCHAR * and not BSTR.
-	m_chmFile = chm_open( (BSTR) filename.toStdWString().c_str() );
+	m_chmFile = chm_open( ( BSTR ) filename.toStdWString().c_str() );
 #else
-	m_chmFile = chm_open( QFile::encodeName(filename) );
+	m_chmFile = chm_open( QFile::encodeName( filename ) );
 #endif
 
 	if ( m_chmFile == NULL )
@@ -299,10 +300,10 @@ bool EBook_CHM::load(const QString& archiveName)
 	guessTextEncoding();
 
 	// Check whether the search tables are present
-	if ( ResolveObject("/#TOPICS", &m_chmTOPICS)
-	        && ResolveObject("/#STRINGS", &m_chmSTRINGS)
-	        && ResolveObject("/#URLTBL", &m_chmURLTBL)
-	        && ResolveObject("/#URLSTR", &m_chmURLSTR) )
+	if ( ResolveObject( "/#TOPICS", &m_chmTOPICS )
+	        && ResolveObject( "/#STRINGS", &m_chmSTRINGS )
+	        && ResolveObject( "/#URLTBL", &m_chmURLTBL )
+	        && ResolveObject( "/#URLSTR", &m_chmURLSTR ) )
 	{
 		m_lookupTablesValid = true;
 		fillTopicsUrlMap();
@@ -329,17 +330,17 @@ bool EBook_CHM::load(const QString& archiveName)
 	return true;
 }
 
-int EBook_CHM::findStringInQuotes (const QString& tag, int offset, QString& value, bool firstquote, bool decodeentities) const
+int EBook_CHM::findStringInQuotes( const QString& tag, int offset, QString& value, bool firstquote, bool decodeentities ) const
 {
-	int qbegin = tag.indexOf ('"', offset);
+	int qbegin = tag.indexOf( '"', offset );
 
 	if ( qbegin == -1 )
-		qFatal ("EBook_CHMImpl::findStringInQuotes: cannot find first quote in <param> tag: '%s'", qPrintable( tag ));
+		qFatal( "EBook_CHMImpl::findStringInQuotes: cannot find first quote in <param> tag: '%s'", qPrintable( tag ) );
 
-	int qend = firstquote ? tag.indexOf ('"', qbegin + 1) : tag.lastIndexOf ('"');
+	int qend = firstquote ? tag.indexOf( '"', qbegin + 1 ) : tag.lastIndexOf( '"' );
 
 	if ( qend == -1 || qend <= qbegin )
-		qFatal ("EBook_CHMImpl::findStringInQuotes: cannot find last quote in <param> tag: '%s'", qPrintable( tag ));
+		qFatal( "EBook_CHMImpl::findStringInQuotes: cannot find last quote in <param> tag: '%s'", qPrintable( tag ) );
 
 	// If we do not need to decode HTML entities, just return.
 	if ( decodeentities )
@@ -347,7 +348,7 @@ int EBook_CHM::findStringInQuotes (const QString& tag, int offset, QString& valu
 		QString htmlentity = QString();
 		bool fill_entity = false;
 
-		value.reserve (qend - qbegin); // to avoid multiple memory allocations
+		value.reserve( qend - qbegin );  // to avoid multiple memory allocations
 
 		for ( int i = qbegin + 1; i < qend; i++ )
 		{
@@ -356,7 +357,7 @@ int EBook_CHM::findStringInQuotes (const QString& tag, int offset, QString& valu
 				if ( tag[i] == '&' ) // HTML entity starts
 					fill_entity = true;
 				else
-					value.append (tag[i]);
+					value.append( tag[i] );
 			}
 			else
 			{
@@ -368,17 +369,17 @@ int EBook_CHM::findStringInQuotes (const QString& tag, int offset, QString& valu
 					if ( decode.isNull() )
 						break;
 
-					value.append ( decode );
+					value.append( decode );
 					htmlentity = QString();
 					fill_entity = false;
 				}
 				else
-					htmlentity.append (tag[i]);
+					htmlentity.append( tag[i] );
 			}
 		}
 	}
 	else
-		value = tag.mid (qbegin + 1, qend - qbegin - 1);
+		value = tag.mid( qbegin + 1, qend - qbegin - 1 );
 
 	return qend + 1;
 }
@@ -413,49 +414,50 @@ bool EBook_CHM::parseFileAndFillArray( const QString& file, QList< ParsedEntry >
 	// Split the HHC file by HTML tags
 	int stringlen = src.length();
 
-	while ( pos < stringlen && (pos = src.indexOf ('<', pos)) != -1 )
+	while ( pos < stringlen && ( pos = src.indexOf( '<', pos ) ) != -1 )
 	{
 		int i, word_end = 0;
 
 		for ( i = ++pos; i < stringlen; i++ )
 		{
 			// If a " or ' is found, skip to the next one.
-			if ( (src[i] == '"' || src[i] == '\'') )
+			if ( ( src[i] == '"' || src[i] == '\'' ) )
 			{
 				// find where quote ends, either by another quote, or by '>' symbol (some people don't know HTML)
-				int nextpos = src.indexOf (src[i], i + 1);
-				if ( nextpos == -1  && (nextpos = src.indexOf ('>', i + 1)) == -1 )
+				int nextpos = src.indexOf( src[i], i + 1 );
+
+				if ( nextpos == -1  && ( nextpos = src.indexOf( '>', i + 1 ) ) == -1 )
 				{
-					qWarning ("EBook_CHMImpl::ParseHhcAndFillTree: corrupted TOC: %s", qPrintable( src.mid(i) ));
+					qWarning( "EBook_CHMImpl::ParseHhcAndFillTree: corrupted TOC: %s", qPrintable( src.mid( i ) ) );
 					return false;
 				}
 
 				i =  nextpos;
 			}
-			else if ( src[i] == '>'  )
+			else if ( src[i] == '>' )
 				break;
 			else if ( !src[i].isLetterOrNumber() && src[i] != '/' && !word_end )
 				word_end = i;
 		}
 
-		QString tagword, tag = src.mid (pos, i - pos);
+		QString tagword, tag = src.mid( pos, i - pos );
 
 		if ( word_end )
-			tagword = src.mid (pos, word_end - pos).toLower();
+			tagword = src.mid( pos, word_end - pos ).toLower();
 		else
 			tagword = tag.toLower();
 
 		//DEBUGPARSER(("tag: '%s', tagword: '%s'\n", qPrintable( tag ), qPrintable( tagword ) ));
 
 		// <OBJECT type="text/sitemap"> - a topic entry
-		if ( tagword == "object" && tag.indexOf ("text/sitemap", 0, Qt::CaseInsensitive ) != -1 )
+		if ( tagword == "object" && tag.indexOf( "text/sitemap", 0, Qt::CaseInsensitive ) != -1 )
 			in_object = true;
 		else if ( tagword == "/object" && in_object )
 		{
 			// a topic entry closed. Add a tree item
 			if ( entry.name.isEmpty() && entry.urls.isEmpty() )
 			{
-				qWarning ("EBook_CHMImpl::ParseAndFillTopicsTree: <object> tag is parsed, but both name and url are empty.");
+				qWarning( "EBook_CHMImpl::ParseAndFillTopicsTree: <object> tag is parsed, but both name and url are empty." );
 			}
 			else
 			{
@@ -469,7 +471,7 @@ bool EBook_CHM::parseFileAndFillArray( const QString& file, QList< ParsedEntry >
 					root_indent_offset = indent;
 
 					if ( root_indent_offset > 1 )
-						qWarning("CHM has improper index; root indent offset is %d", root_indent_offset);
+						qWarning( "CHM has improper index; root indent offset is %d", root_indent_offset );
 				}
 
 				// Trim the entry name
@@ -494,18 +496,18 @@ bool EBook_CHM::parseFileAndFillArray( const QString& file, QList< ParsedEntry >
 			QString name_pattern = "name=", value_pattern = "value=";
 			QString pname, pvalue;
 
-			if ( (offset = tag.indexOf (name_pattern, 0, Qt::CaseInsensitive )) == -1 )
-				qFatal ("EBook_CHMImpl::ParseAndFillTopicsTree: bad <param> tag '%s': no name=\n", qPrintable( tag ));
+			if ( ( offset = tag.indexOf( name_pattern, 0, Qt::CaseInsensitive ) ) == -1 )
+				qFatal( "EBook_CHMImpl::ParseAndFillTopicsTree: bad <param> tag '%s': no name=\n", qPrintable( tag ) );
 
 			// offset+5 skips 'name='
-			offset = findStringInQuotes (tag, offset + name_pattern.length(), pname, true, false);
+			offset = findStringInQuotes( tag, offset + name_pattern.length(), pname, true, false );
 			pname = pname.toLower();
 
-			if ( (offset = tag.indexOf(value_pattern, offset, Qt::CaseInsensitive )) == -1 )
-				qFatal ("EBook_CHMImpl::ParseAndFillTopicsTree: bad <param> tag '%s': no value=\n", qPrintable( tag ));
+			if ( ( offset = tag.indexOf( value_pattern, offset, Qt::CaseInsensitive ) ) == -1 )
+				qFatal( "EBook_CHMImpl::ParseAndFillTopicsTree: bad <param> tag '%s': no value=\n", qPrintable( tag ) );
 
 			// offset+6 skips 'value='
-			findStringInQuotes (tag, offset + value_pattern.length(), pvalue, false, true);
+			findStringInQuotes( tag, offset + value_pattern.length(), pvalue, false, true );
 
 			//DEBUGPARSER(("<param>: name '%s', value '%s'", qPrintable( pname ), qPrintable( pvalue )));
 
@@ -532,7 +534,7 @@ bool EBook_CHM::parseFileAndFillArray( const QString& file, QList< ParsedEntry >
 					stringlen = src.length();
 				}
 				else
-					qWarning( "MERGE is used in index but file %s was not found in CHM archive", qPrintable(pvalue) );
+					qWarning( "MERGE is used in index but file %s was not found in CHM archive", qPrintable( pvalue ) );
 			}
 			else if ( pname == "local" )
 			{
@@ -544,32 +546,32 @@ bool EBook_CHM::parseFileAndFillArray( const QString& file, QList< ParsedEntry >
 			}
 			else if ( pname == "see also" && asIndex && entry.name != pvalue )
 			{
-				entry.urls.push_back( QUrl("seealso") );
+				entry.urls.push_back( QUrl( "seealso" ) );
 				entry.seealso = pvalue;
 			}
 			else if ( pname == "imagenumber" )
 			{
 				bool bok;
-				int imgnum = pvalue.toInt (&bok);
+				int imgnum = pvalue.toInt( &bok );
 
 				if ( bok && imgnum >= 0 && imgnum < EBookTocEntry::MAX_BUILTIN_ICONS )
-					entry.iconid = (EBookTocEntry::Icon) imgnum;
+					entry.iconid = ( EBookTocEntry::Icon ) imgnum;
 			}
 		}
 		else if ( tagword == "ul" ) // increase indent level
 		{
 			// Fix for buggy help files
 			if ( ++indent >= MAX_NEST_DEPTH )
-				qFatal("EBook_CHMImpl::ParseAndFillTopicsTree: max nest depth (%d) is reached, error in help file", MAX_NEST_DEPTH);
+				qFatal( "EBook_CHMImpl::ParseAndFillTopicsTree: max nest depth (%d) is reached, error in help file", MAX_NEST_DEPTH );
 
-			DEBUGPARSER(("<ul>: new intent is %d\n", indent - root_indent_offset));
+			DEBUGPARSER( ( "<ul>: new intent is %d\n", indent - root_indent_offset ) );
 		}
 		else if ( tagword == "/ul" ) // decrease indent level
 		{
 			if ( --indent < root_indent_offset )
 				indent = root_indent_offset;
 
-			DEBUGPARSER(("</ul>: new intent is %d\n", indent - root_indent_offset));
+			DEBUGPARSER( ( "</ul>: new intent is %d\n", indent - root_indent_offset ) );
 		}
 
 		pos = i;
@@ -582,27 +584,27 @@ bool EBook_CHM::parseFileAndFillArray( const QString& file, QList< ParsedEntry >
 	return true;
 }
 
-bool EBook_CHM::ResolveObject(const QString& fileName, chmUnitInfo* ui) const
+bool EBook_CHM::ResolveObject( const QString& fileName, chmUnitInfo* ui ) const
 {
 	return m_chmFile != NULL
-	       && ::chm_resolve_object(m_chmFile, qPrintable( fileName ), ui) ==
+	       && ::chm_resolve_object( m_chmFile, qUtf8Printable( fileName ), ui ) ==
 	       CHM_RESOLVE_SUCCESS;
 }
 
-bool EBook_CHM::hasFile(const QString& fileName) const
+bool EBook_CHM::hasFile( const QString& fileName ) const
 {
 	chmUnitInfo ui;
 
 	return m_chmFile != NULL
-	       && ::chm_resolve_object(m_chmFile, qPrintable( fileName ), &ui) ==
+	       && ::chm_resolve_object( m_chmFile, qPrintable( fileName ), &ui ) ==
 	       CHM_RESOLVE_SUCCESS;
 }
 
-size_t EBook_CHM::RetrieveObject(const chmUnitInfo* ui, unsigned char* buffer,
-                                 LONGUINT64 fileOffset, LONGINT64 bufferSize) const
+size_t EBook_CHM::RetrieveObject( const chmUnitInfo* ui, unsigned char* buffer,
+                                  LONGUINT64 fileOffset, LONGINT64 bufferSize ) const
 {
-	return ::chm_retrieve_object(m_chmFile, const_cast<chmUnitInfo*>(ui),
-	                             buffer, fileOffset, bufferSize);
+	return ::chm_retrieve_object( m_chmFile, const_cast<chmUnitInfo*>( ui ),
+	                              buffer, fileOffset, bufferSize );
 }
 
 bool EBook_CHM::getInfoFromWindows()
@@ -613,68 +615,69 @@ bool EBook_CHM::getInfoFromWindows()
 	chmUnitInfo ui;
 	size_t size = 0;
 
-	if ( ResolveObject("/#WINDOWS", &ui) )
+	if ( ResolveObject( "/#WINDOWS", &ui ) )
 	{
-		if ( !RetrieveObject(&ui, buffer, 0, WIN_HEADER_LEN) )
+		if ( !RetrieveObject( &ui, buffer, 0, WIN_HEADER_LEN ) )
 			return false;
 
-		unsigned int entries = get_int32_le( (unsigned int*)(buffer) );
-		unsigned int entry_size = get_int32_le( (unsigned int*)(buffer + 0x04) );
+		unsigned int entries = get_int32_le( ( unsigned int* )( buffer ) );
+		unsigned int entry_size = get_int32_le( ( unsigned int* )( buffer + 0x04 ) );
 
-		QVector<unsigned char> uptr(entries * entry_size);
-		unsigned char* raw = (unsigned char*) uptr.data();
+		QVector<unsigned char> uptr( entries * entry_size );
+		unsigned char* raw = ( unsigned char* ) uptr.data();
 
-		if ( !RetrieveObject (&ui, raw, 8, entries * entry_size) )
+		if ( !RetrieveObject( &ui, raw, 8, entries * entry_size ) )
 			return false;
 
-		if ( !ResolveObject ("/#STRINGS", &ui) )
+		if ( !ResolveObject( "/#STRINGS", &ui ) )
 			return false;
 
 		for ( unsigned int i = 0; i < entries; ++i )
 		{
 			unsigned int offset = i * entry_size;
 
-			unsigned int off_title = get_int32_le( (unsigned int*)(raw + offset + 0x14) );
-			unsigned int off_home = get_int32_le( (unsigned int*)(raw + offset + 0x68) );
-			unsigned int off_hhc = get_int32_le( (unsigned int*)(raw + offset + 0x60) );
-			unsigned int off_hhk = get_int32_le( (unsigned int*)(raw + offset + 0x64) );
+			unsigned int off_title = get_int32_le( ( unsigned int* )( raw + offset + 0x14 ) );
+			unsigned int off_home = get_int32_le( ( unsigned int* )( raw + offset + 0x68 ) );
+			unsigned int off_hhc = get_int32_le( ( unsigned int* )( raw + offset + 0x60 ) );
+			unsigned int off_hhk = get_int32_le( ( unsigned int* )( raw + offset + 0x64 ) );
 
 			factor = off_title / 4096;
 
 			if ( size == 0 )
-				size = RetrieveObject(&ui, buffer, factor * 4096, BUF_SIZE);
+				size = RetrieveObject( &ui, buffer, factor * 4096, BUF_SIZE );
 
 			if ( size && off_title )
-				m_title = QByteArray( (const char*) (buffer + off_title % 4096) );
+				m_title = QByteArray( ( const char* )( buffer + off_title % 4096 ) );
 
-			if ( factor != off_home / 4096)
+			if ( factor != off_home / 4096 )
 			{
 				factor = off_home / 4096;
-				size = RetrieveObject (&ui, buffer, factor * 4096, BUF_SIZE);
+				size = RetrieveObject( &ui, buffer, factor * 4096, BUF_SIZE );
 			}
 
 			if ( size && off_home )
-				m_home = QByteArray("/") + QByteArray( (const char*) buffer + off_home % 4096);
+				m_home = QByteArray( "/" ) + QByteArray( ( const char* ) buffer + off_home % 4096 );
 
-			if ( factor != off_hhc / 4096)
+			if ( factor != off_hhc / 4096 )
 			{
 				factor = off_hhc / 4096;
-				size = RetrieveObject(&ui, buffer, factor * 4096, BUF_SIZE);
+				size = RetrieveObject( &ui, buffer, factor * 4096, BUF_SIZE );
 			}
 
 			if ( size && off_hhc )
-				m_topicsFile = QByteArray("/") + QByteArray((const char*) buffer + off_hhc % 4096);
+				m_topicsFile = QByteArray( "/" ) + QByteArray( ( const char* ) buffer + off_hhc % 4096 );
 
-			if ( factor != off_hhk / 4096)
+			if ( factor != off_hhk / 4096 )
 			{
 				factor = off_hhk / 4096;
-				size = RetrieveObject (&ui, buffer, factor * 4096, BUF_SIZE);
+				size = RetrieveObject( &ui, buffer, factor * 4096, BUF_SIZE );
 			}
 
 			if ( size && off_hhk )
-				m_indexFile = QByteArray("/") + QByteArray((const char*) buffer + off_hhk % 4096);
+				m_indexFile = QByteArray( "/" ) + QByteArray( ( const char* ) buffer + off_hhk % 4096 );
 		}
 	}
+
 	return true;
 }
 
@@ -684,35 +687,35 @@ bool EBook_CHM::getInfoFromSystem()
 	chmUnitInfo ui;
 
 	size_t index = 0;
-	unsigned char* cursor = NULL, *p;
+	unsigned char* cursor = NULL, * p;
 	unsigned short value = 0;
 	size_t size = 0;
 
 	// Run the first loop to detect the encoding. We need this, because title could be
 	// already encoded in user encoding. Same for file names
-	if ( !ResolveObject ("/#SYSTEM", &ui) )
+	if ( !ResolveObject( "/#SYSTEM", &ui ) )
 		return false;
 
 	// Can we pull BUFF_SIZE bytes of the #SYSTEM file?
-	if ( (size = RetrieveObject (&ui, buffer, 4, BUF_SIZE)) == 0 )
+	if ( ( size = RetrieveObject( &ui, buffer, 4, BUF_SIZE ) ) == 0 )
 		return false;
 
 	buffer[size - 1] = 0;
 
 	// First loop to detect the encoding
-	for ( index = 0; index + 1 + sizeof(unsigned short) < size;)
+	for ( index = 0; index + 1 + sizeof( unsigned short ) < size; )
 	{
 		cursor = buffer + index;
-		value = UINT16ARRAY(cursor);
+		value = UINT16ARRAY( cursor );
 
-		switch (value)
+		switch ( value )
 		{
 		case 0:
 			index += 2;
 			cursor = buffer + index;
 
-			if (m_topicsFile.isEmpty())
-				m_topicsFile = QByteArray("/") + QByteArray((const char*) buffer + index + 2);
+			if ( m_topicsFile.isEmpty() )
+				m_topicsFile = QByteArray( "/" ) + QByteArray( ( const char* ) buffer + index + 2 );
 
 			break;
 
@@ -720,22 +723,24 @@ bool EBook_CHM::getInfoFromSystem()
 			index += 2;
 			cursor = buffer + index;
 
-			if (m_indexFile.isEmpty())
-				m_indexFile = QByteArray("/") + QByteArray((const char*)buffer + index + 2);
+			if ( m_indexFile.isEmpty() )
+				m_indexFile = QByteArray( "/" ) + QByteArray( ( const char* )buffer + index + 2 );
+
 			break;
 
 		case 2:
 			index += 2;
 			cursor = buffer + index;
 
-			if (m_home.isEmpty() || m_home == "/")
-				m_home = QByteArray("/") + QByteArray((const char*) buffer + index + 2);
+			if ( m_home.isEmpty() || m_home == "/" )
+				m_home = QByteArray( "/" ) + QByteArray( ( const char* ) buffer + index + 2 );
+
 			break;
 
 		case 3:
 			index += 2;
 			cursor = buffer + index;
-			m_title = QByteArray( (const char*) (buffer + index + 2) );
+			m_title = QByteArray( ( const char* )( buffer + index + 2 ) );
 			break;
 
 		case 4:
@@ -743,7 +748,7 @@ bool EBook_CHM::getInfoFromSystem()
 			cursor = buffer + index;
 
 			p = buffer + index + 2;
-			m_detectedLCID = (short) (p[0] | (p[1] << 8));
+			m_detectedLCID = ( short )( p[0] | ( p[1] << 8 ) );
 
 			break;
 
@@ -754,25 +759,26 @@ bool EBook_CHM::getInfoFromSystem()
 			if ( m_topicsFile.isEmpty() )
 			{
 				QString topicAttempt = "/", tmp;
-				topicAttempt += QString ((const char*) buffer + index + 2);
+				topicAttempt += QString( ( const char* ) buffer + index + 2 );
 
 				tmp = topicAttempt + ".hhc";
 
-				if ( ResolveObject( tmp, &ui) )
+				if ( ResolveObject( tmp, &ui ) )
 					m_topicsFile = qPrintable( tmp );
 
 				tmp = topicAttempt + ".hhk";
 
-				if ( ResolveObject( tmp, &ui) )
+				if ( ResolveObject( tmp, &ui ) )
 					m_indexFile = qPrintable( tmp );
 			}
+
 			break;
 
 		case 16:
 			index += 2;
 			cursor = buffer + index;
 
-			m_font = QString ((const char*) buffer + index + 2);
+			m_font = QString( ( const char* ) buffer + index + 2 );
 			break;
 
 		default:
@@ -780,7 +786,7 @@ bool EBook_CHM::getInfoFromSystem()
 			cursor = buffer + index;
 		}
 
-		value = UINT16ARRAY(cursor);
+		value = UINT16ARRAY( cursor );
 		index += value + 2;
 	}
 
@@ -800,11 +806,11 @@ QString EBook_CHM::getTopicByUrl( const QUrl& url )
 static int chm_enumerator_callback( struct chmFile*, struct chmUnitInfo* ui, void* context )
 {
 	EBook_CHM tmp;
-	((QList<QUrl>*) context)->push_back( tmp.pathToUrl( ui->path ) );
+	( ( QList<QUrl>* ) context )->push_back( tmp.pathToUrl( ui->path ) );
 	return CHM_ENUMERATOR_CONTINUE;
 }
 
-bool EBook_CHM::enumerateFiles(QList<QUrl>& files )
+bool EBook_CHM::enumerateFiles( QList<QUrl>& files )
 {
 	files.clear();
 	return chm_enumerate( m_chmFile, CHM_ENUMERATE_ALL, chm_enumerator_callback, &files );
@@ -821,7 +827,7 @@ bool EBook_CHM::setCurrentEncoding( const char* encoding )
 	return changeFileEncoding( encoding );
 }
 
-bool EBook_CHM::isSupportedUrl(const QUrl& url)
+bool EBook_CHM::isSupportedUrl( const QUrl& url )
 {
 	return url.scheme() == URL_SCHEME_CHM;
 }
@@ -830,13 +836,13 @@ bool EBook_CHM::guessTextEncoding()
 {
 	if ( !m_detectedLCID )
 	{
-		qFatal ("Could not detect LCID");
+		qFatal( "Could not detect LCID" );
 		return false;
 	}
 
 	QString enc = Ebook_CHM_Encoding::guessByLCID( m_detectedLCID );
 
-	if ( changeFileEncoding ( enc ) )
+	if ( changeFileEncoding( enc ) )
 	{
 		m_currentEncoding = enc;
 		return true;
@@ -845,7 +851,7 @@ bool EBook_CHM::guessTextEncoding()
 	return false;
 }
 
-bool EBook_CHM::changeFileEncoding( const QString& qtencoding  )
+bool EBook_CHM::changeFileEncoding( const QString& qtencoding )
 {
 	// Encoding could be either simple Qt codepage, or set like CP1251/KOI8, which allows to
 	// set up encodings separately for text (first) and internal files (second)
@@ -897,22 +903,22 @@ void EBook_CHM::fillTopicsUrlMap()
 	// Read those tables
 	QVector<unsigned char> topics( m_chmTOPICS.length ), urltbl( m_chmURLTBL.length ), urlstr( m_chmURLSTR.length ), strings( m_chmSTRINGS.length );
 
-	if ( !RetrieveObject( &m_chmTOPICS, (unsigned char*) topics.data(), 0, m_chmTOPICS.length )
-	        || !RetrieveObject( &m_chmURLTBL, (unsigned char*) urltbl.data(), 0, m_chmURLTBL.length )
-	        || !RetrieveObject( &m_chmURLSTR, (unsigned char*) urlstr.data(), 0, m_chmURLSTR.length )
-	        || !RetrieveObject( &m_chmSTRINGS, (unsigned char*) strings.data(), 0, m_chmSTRINGS.length ) )
+	if ( !RetrieveObject( &m_chmTOPICS, ( unsigned char* ) topics.data(), 0, m_chmTOPICS.length )
+	        || !RetrieveObject( &m_chmURLTBL, ( unsigned char* ) urltbl.data(), 0, m_chmURLTBL.length )
+	        || !RetrieveObject( &m_chmURLSTR, ( unsigned char* ) urlstr.data(), 0, m_chmURLSTR.length )
+	        || !RetrieveObject( &m_chmSTRINGS, ( unsigned char* ) strings.data(), 0, m_chmSTRINGS.length ) )
 		return;
 
 	for ( unsigned int i = 0; i < m_chmTOPICS.length; i += TOPICS_ENTRY_LEN )
 	{
-		unsigned int off_title = get_int32_le( (unsigned int*)(topics.data() + i + 4) );
-		unsigned int off_url = get_int32_le( (unsigned int*)(topics.data() + i + 8) );
-		off_url = get_int32_le( (unsigned int*)( urltbl.data() + off_url + 8) ) + 8;
+		unsigned int off_title = get_int32_le( ( unsigned int* )( topics.data() + i + 4 ) );
+		unsigned int off_url = get_int32_le( ( unsigned int* )( topics.data() + i + 8 ) );
+		off_url = get_int32_le( ( unsigned int* )( urltbl.data() + off_url + 8 ) ) + 8;
 
-		QUrl url = pathToUrl( (const char*) urlstr.data() + off_url );
+		QUrl url = pathToUrl( ( const char* ) urlstr.data() + off_url );
 
-		if ( off_title < (unsigned int)strings.size() )
-			m_url2topics[url] = encodeWithCurrentCodec ( (const char*) strings.data() + off_title );
+		if ( off_title < ( unsigned int )strings.size() )
+			m_url2topics[url] = encodeWithCurrentCodec( ( const char* ) strings.data() + off_title );
 		else
 			m_url2topics[url] = "Untitled";
 	}
@@ -936,7 +942,7 @@ bool EBook_CHM::parseBinaryTOC( QList< EBookTocEntry >& toc ) const
 	// Shamelessly stolen from xchm
 	if ( !RecurseLoadBTOC( tocidx, topics, urltbl, urlstr, strings, UINT32ARRAY( tocidx.data() ),  toc, 0 ) )
 	{
-		qWarning("Failed to parse binary TOC, fallback to text-based TOC");
+		qWarning( "Failed to parse binary TOC, fallback to text-based TOC" );
 		toc.clear();
 		return false;
 	}
@@ -965,33 +971,33 @@ bool EBook_CHM::RecurseLoadBTOC( const QByteArray& tocidx,
 		unsigned int flags = UINT32ARRAY( tocidx.data() + offset + 4 );
 		int index = UINT32ARRAY( tocidx.data() + offset + 8 );
 
-		if ( (flags & 0x04) || (flags & 0x08))
+		if ( ( flags & 0x04 ) || ( flags & 0x08 ) )
 		{
 			QString name, value;
 
-			if ( (flags & 0x08) == 0 )
+			if ( ( flags & 0x08 ) == 0 )
 			{
 				if ( strings.size() < index + 1 )
 				{
-					qWarning("EBook_CHM::RecurseLoadBTOC: invalid name index (%d) for book TOC entry!", index );
+					qWarning( "EBook_CHM::RecurseLoadBTOC: invalid name index (%d) for book TOC entry!", index );
 					return false;
 				}
 
-				name = encodeInternalWithCurrentCodec( strings.data() + index);
+				name = encodeInternalWithCurrentCodec( strings.data() + index );
 			}
 			else
 			{
-				if ( topics.size() < (index * 16) + 12 )
+				if ( topics.size() < ( index * 16 ) + 12 )
 				{
-					qWarning("EBook_CHM::RecurseLoadBTOC: invalid name index (%d) for local TOC entry!", index );
+					qWarning( "EBook_CHM::RecurseLoadBTOC: invalid name index (%d) for local TOC entry!", index );
 					return false;
 				}
 
-				int tocoffset = (int) UINT32ARRAY(topics.data() + (index * 16) + 4);
+				int tocoffset = ( int ) UINT32ARRAY( topics.data() + ( index * 16 ) + 4 );
 
 				if ( strings.size() < tocoffset + 1 )
 				{
-					qWarning("EBook_CHM::RecurseLoadBTOC: invalid name tocoffset (%d) for TOC entry!", tocoffset );
+					qWarning( "EBook_CHM::RecurseLoadBTOC: invalid name tocoffset (%d) for TOC entry!", tocoffset );
 					return false;
 				}
 
@@ -1001,19 +1007,19 @@ bool EBook_CHM::RecurseLoadBTOC( const QByteArray& tocidx,
 					name = encodeInternalWithCurrentCodec( strings.data() + tocoffset );
 
 				// #URLTBL index
-				tocoffset = (int) UINT32ARRAY( topics.data() + (index * 16) + 8 );
+				tocoffset = ( int ) UINT32ARRAY( topics.data() + ( index * 16 ) + 8 );
 
 				if ( tocoffset < 0 || urltbl.size() < tocoffset + 12 )
 				{
-					qWarning("EBook_CHM::RecurseLoadBTOC: invalid url index (%d) for TOC entry!", tocoffset );
+					qWarning( "EBook_CHM::RecurseLoadBTOC: invalid url index (%d) for TOC entry!", tocoffset );
 					return false;
 				}
 
-				tocoffset = (int) UINT32ARRAY(urltbl.data() + tocoffset + 8);
+				tocoffset = ( int ) UINT32ARRAY( urltbl.data() + tocoffset + 8 );
 
 				if ( tocoffset < 0 || urlstr.size() < tocoffset )
 				{
-					qWarning("EBook_CHM::RecurseLoadBTOC: invalid url offset (%d) for TOC entry!", tocoffset );
+					qWarning( "EBook_CHM::RecurseLoadBTOC: invalid url offset (%d) for TOC entry!", tocoffset );
 					return false;
 				}
 
@@ -1039,7 +1045,7 @@ bool EBook_CHM::RecurseLoadBTOC( const QByteArray& tocidx,
 			// book
 			if ( tocidx.size() < offset + 24 )
 			{
-				qWarning("EBook_CHM::RecurseLoadBTOC: invalid child entry offset (%d)", offset );
+				qWarning( "EBook_CHM::RecurseLoadBTOC: invalid child entry offset (%d)", offset );
 				return false;
 			}
 
@@ -1058,7 +1064,7 @@ bool EBook_CHM::RecurseLoadBTOC( const QByteArray& tocidx,
 	return true;
 }
 
-bool EBook_CHM::hasOption(const QString& name) const
+bool EBook_CHM::hasOption( const QString& name ) const
 {
 	if ( !m_envOptions.isEmpty() && m_envOptions.contains( name ) )
 		return true;
@@ -1066,7 +1072,7 @@ bool EBook_CHM::hasOption(const QString& name) const
 	return false;
 }
 
-QUrl EBook_CHM::pathToUrl(const QString& link) const
+QUrl EBook_CHM::pathToUrl( const QString& link ) const
 {
 	if ( link.startsWith( "http://" ) || link.startsWith( "https://" ) )
 		return QUrl( link );
@@ -1094,7 +1100,7 @@ QUrl EBook_CHM::pathToUrl(const QString& link) const
 	return url;
 }
 
-QString EBook_CHM::urlToPath(const QUrl& link) const
+QString EBook_CHM::urlToPath( const QUrl& link ) const
 {
 	if ( link.scheme() == URL_SCHEME_CHM )
 	{
